@@ -140,12 +140,14 @@ public:
       }else
       {
 //         kDebug() << "compiling";
-        LockedSmartInterface iface = m_editor->smart();
-        top = newTopContext( iface.currentDocument()
-                                    ? SimpleRange( iface.currentDocument()->documentRange() )
-                                    : SimpleRange( SimpleCursor( 0, 0 ), SimpleCursor( INT_MAX, INT_MAX ) ) );
-        top->setSmartRange( m_editor->topRange( iface, EditorIntegrator::DefinitionUseChain ), DocumentRangeObject::Own );
-        top->setType( DUContext::Global );
+        {
+          LockedSmartInterface iface = m_editor->smart();
+          top = newTopContext( iface.currentDocument()
+                                      ? SimpleRange( iface.currentDocument()->documentRange() )
+                                      : SimpleRange( SimpleCursor( 0, 0 ), SimpleCursor( INT_MAX, INT_MAX ) ) );
+          top->setSmartRange( m_editor->topRange( iface, EditorIntegrator::DefinitionUseChain ), DocumentRangeObject::Own );
+          top->setType( DUContext::Global );
+        }
         DUChain::self()->addDocumentChain( top );
       }
       setEncountered( top );
@@ -303,6 +305,10 @@ protected:
 
   inline void setLastContext(DUContext* context) { m_lastContext = context; }
 
+  TopDUContext* topContext() const {
+    return currentContext()->topContext();
+  }
+
   /**
    * Determine if we are recompiling an existing definition-use chain, or if
    * a new chain is being created from scratch.
