@@ -49,40 +49,30 @@ DumpChain::~ DumpChain( )
 
 void DumpChain::dump( DUContext * context, int allowedDepth )
 {
-    if(!top)
-      top = context->topContext();
-    
-          enum ContextType {
-    Global    /**< A context that declares functions, namespaces or classes */,
-    Namespace /**< A context that declares namespace members */,
-    Class     /**< A context that declares class members */,
-    Function  /**< A context that declares function-arguments */,
-    Template  /**< A context that declares template-parameters */,
-    Enum      /**< A context that contains a list of enumerators */,
-    Helper    /**< A helper context, used for language-specific tweaks */,
-    Other     /**< Represents executable code, like for example within a compound-statement */
-  };
+  if(!top)
+    top = context->topContext();
+
   QString type;
   switch(context->type()) {
-    case Global: type = "Global"; break;
-    case Namespace: type = "Namespace"; break;
-    case Class: type = "Class"; break;
-    case Function: type = "Function"; break;
-    case Template: type = "Template"; break;
-    case Enum: type = "Enum"; break;
-    case Helper: type = "Helper"; break;
-    case Other: type = "Other"; break;
+    case DUContext::Global: type = "Global"; break;
+    case DUContext::Namespace: type = "Namespace"; break;
+    case DUContext::Class: type = "Class"; break;
+    case DUContext::Function: type = "Function"; break;
+    case DUContext::Template: type = "Template"; break;
+    case DUContext::Enum: type = "Enum"; break;
+    case DUContext::Helper: type = "Helper"; break;
+    case DUContext::Other: type = "Other"; break;
   }
   kDebug() << QString(indent * 2, ' ') << (indent ? "==import==> Context " : "New Context ") << type << context << "\"" <<  context->localScopeIdentifier() << "\" [" << context->scopeIdentifier() << "]" << context->range().textRange() << ' ' << (dynamic_cast<TopDUContext*>(context) ? "top-context" : "");
 
-      
+
   if( !context )
     return;
   if (allowedDepth >= 0) {
     foreach (Declaration* dec, context->localDeclarations(top)) {
-      
+
       //IdentifiedType* idType = dynamic_cast<IdentifiedType*>(dec->abstractType().data());
-      
+
       kDebug() << QString((indent+1) * 2, ' ') << "Declaration: " << dec->toString() << /*(idType ? (" (type-identity: " + idType->identifier().toString() + ")") : QString()) <<*/ " [" << dec->qualifiedIdentifier() << "]" << dec << "(internal ctx" << dec->internalContext() << ")" << dec->range().textRange() << "smart range:" << dec->smartRange() << "," << (dec->isDefinition() ? "defined, " : (FunctionDefinition::definition(dec) ? "" : "no definition, ")) << dec->uses().count() << "use(s).";
       if (FunctionDefinition::definition(dec)) {
         kDebug() << QString((indent+1) * 2 + 1, ' ') << "Definition:" << FunctionDefinition::definition(dec)->range().textRange();
@@ -90,8 +80,9 @@ void DumpChain::dump( DUContext * context, int allowedDepth )
       QMap<IndexedString, QList<SimpleRange> > uses = dec->uses();
       for(QMap<IndexedString, QList<SimpleRange> >::const_iterator it = uses.constBegin(); it != uses.constEnd(); ++it) {
         kDebug() << QString((indent+2) * 2, ' ') << "File:" << it.key().str();
-        foreach (const SimpleRange& range, *it)
+        foreach (const SimpleRange& range, *it) {
           kDebug() << QString((indent+2) * 2+1, ' ') << "Use:" << range.textRange();
+        }
       }
     }
   } else {
@@ -106,21 +97,22 @@ void DumpChain::dump( DUContext * context, int allowedDepth )
           kDebug() << QString((indent+2) * 2+1, ' ') << "Could not get parent, is it registered in the DUChain?";
           continue;
       }
-      
+
       if(had.contains(import)) {
         kDebug() << QString((indent+2) * 2+1, ' ') << "skipping" << import->scopeIdentifier(true) << "because it was already printed";
         continue;
       }
       had.insert(import);
-      
+
       dump(import, allowedDepth-1);
     }
 
-    foreach (DUContext* child, context->childContexts())
+    foreach (DUContext* child, context->childContexts()) {
       dump(child);
+    }
   }
   --indent;
-  
+
   if(indent == 0) {
     top = 0;
     had.clear();
@@ -134,6 +126,6 @@ QString DumpChain::dumpRanges(KTextEditor::SmartRange* range, QString indent)
   stream << indent << range << "(" << range->start().line() << ", " <<  range->start().column() << ") -> (" << range->end().line() << ", " <<  range->end().column() << ')' << "\n";
   foreach(KTextEditor::SmartRange* child, range->childRanges())
     stream << dumpRanges(child, indent + ' ');
-  
+
   return ret;
 }
