@@ -19,6 +19,7 @@
 #include "itemrepository.h"
 
 #include <QDataStream>
+#include <QUuid>
 
 #include <kstandarddirs.h>
 #include <kcomponentdata.h>
@@ -29,6 +30,7 @@
 #include <interfaces/icore.h>
 
 #include "../duchain.h"
+#include <interfaces/isession.h>
 
 namespace KDevelop {
 
@@ -71,12 +73,12 @@ QPair<QString, KLockFile::Ptr> allocateRepository() {
    KComponentData component("item repositories temp", QByteArray(), KComponentData::SkipMainComponentRegistration);
     QString baseDir = QDir::homePath() + "/.kdevduchain";
     KStandardDirs::makeDir(baseDir);
-    
-    if(getenv("KDEV_SESSION"))
-      baseDir += "/" + QString(getenv("KDEV_SESSION"));
-    else
-      kWarning() << "Missing session environment variable KDEV_SESSION!";
-    
+
+    Q_ASSERT( ICore::self() );
+    Q_ASSERT( ICore::self()->activeSession() );
+
+    baseDir += "/" + ICore::self()->activeSession()->id().toString();
+
     //Since each instance of kdevelop needs an own directory, iterate until we find a not-yet-used one
     for(int a = 0; a < 100; ++a) {
       QString specificDir = baseDir + QString("/%1").arg(a);
@@ -121,7 +123,7 @@ QPair<QString, KLockFile::Ptr> allocateRepository() {
 }
 
 ///The global item-repository registry that is used by default
-ItemRepositoryRegistry& allocateGlobalItemRepositoryRegistry() {
+static ItemRepositoryRegistry& allocateGlobalItemRepositoryRegistry() {
   QPair<QString, KLockFile::Ptr> repo = allocateRepository();
   
   ///We intentionally leak the registry, to prevent problems in the destruction order, where
