@@ -91,6 +91,8 @@ ColorCache::ColorCache(QObject* parent)
   updateColorsFromScheme(); // default / fallback
   updateColorsFromSettings();
 
+  m_defaultColors = new CodeHighlightingColors(this);
+
   connect(ICore::self()->languageController()->completionSettings(), SIGNAL(settingsChanged(ICompletionSettings*)),
            this, SLOT(updateColorsFromSettings()), Qt::QueuedConnection);
 
@@ -117,6 +119,7 @@ ColorCache::~ColorCache()
 {
   m_self = 0;
   delete m_defaultColors;
+  m_defaultColors = 0;
 }
 
 ColorCache* ColorCache::self()
@@ -279,6 +282,7 @@ QColor ColorCache::blendLocalColor(QColor color) const
 
 CodeHighlightingColors* ColorCache::defaultColors() const
 {
+  Q_ASSERT(m_defaultColors);
   return m_defaultColors;
 }
 
