@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright 2007 Robert Gruber <rgruber@users.sourceforge.net>          *
+ *   Copyright 2010 Milian Wolff <mail@milianw.de>                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -8,34 +8,39 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef __EDITSNIPPET_H__
-#define __EDITSNIPPET_H__
-
+#ifndef EDITSNIPPET_H
+#define EDITSNIPPET_H
 
 #include "ui_editsnippet.h"
-#include <kdialog.h>
 
+#include <KDialog>
+
+class SnippetRepository;
 class Snippet;
 
+class QStandardItemModel;
+
 /**
- * A dialog that allows to edit the given snippet
- * @see editsnippet.ui
- * @author Robert Gruber <rgruber@users.sourceforge.net>
+ * This dialog is used to create/edit snippets in a given repository.
+ *
+ * @author Milian Wolff <mail@milianw.de>
  */
-class EditSnippet : public KDialog, public Ui::EditSnippet
+class EditSnippet : public KDialog, public Ui::EditSnippetBase
 {
     Q_OBJECT
 
 public:
-    explicit EditSnippet(Snippet *s, QWidget *parent = 0);
+    /// @p snippet set to 0 when you want to create a new snippet.
+    explicit EditSnippet(SnippetRepository* repo, Snippet* snippet, QWidget* parent = 0);
     virtual ~EditSnippet();
 
-
-public slots:
-    virtual void accept();
-
 private:
-    Snippet *snippet_;
+    SnippetRepository* m_repo;
+    Snippet* m_snippet;
+
+private slots:
+    void save();
+    void validate();
 };
 
 #endif
