@@ -22,9 +22,9 @@
 #include <KActionCollection>
 #include <KAction>
 
-#include <kdeversion.h>
-#if KDE_VERSION >= KDE_MAKE_VERSION(4, 4, 0)
-    #define HAVE_HIGHLIGHT_IFACE
+#include "snippetfeatures.h"
+
+#ifdef SNIPPETS_HAVE_HIGHLIGHTIFACE
     #include <KTextEditor/HighlightInterface>
 #endif
 
@@ -47,6 +47,8 @@
 K_PLUGIN_FACTORY(SnippetFactory, registerPlugin<SnippetPlugin>(); )
 K_EXPORT_PLUGIN(SnippetFactory(KAboutData("kdevsnippet","kdevsnippet", ki18n("Snippets"), "0.1", ki18n("Support for managing and using code snippets"), KAboutData::License_GPL)))
 
+SnippetPlugin* SnippetPlugin::m_self = 0;
+
 class SnippetViewFactory: public KDevelop::IToolViewFactory{
 public:
     SnippetViewFactory(SnippetPlugin *plugin): m_plugin(plugin) {}
@@ -75,6 +77,9 @@ private:
 SnippetPlugin::SnippetPlugin(QObject *parent, const QVariantList &)
   : KDevelop::IPlugin(SnippetFactory::componentData(), parent)
 {
+    Q_ASSERT(!m_self);
+    m_self = this;
+
     SnippetStore::init(this);
 
     m_model = new SnippetCompletionModel;
@@ -89,6 +94,12 @@ SnippetPlugin::SnippetPlugin(QObject *parent, const QVariantList &)
 
 SnippetPlugin::~SnippetPlugin()
 {
+    m_self = 0;
+}
+
+SnippetPlugin* SnippetPlugin::self()
+{
+    return m_self;
 }
 
 void SnippetPlugin::unload()
@@ -102,7 +113,7 @@ void SnippetPlugin::insertSnippet(Snippet* snippet)
     KDevelop::IDocument* doc = core()->documentController()->activeDocument();
     if (!doc) return;
     if (doc->isTextDocument()) {
-        SnippetCompletionItem item(snippet);
+        SnippetCompletionItem item(snippet, static_cast<SnippetRepository*>(snippet->parent()));
         KTextEditor::Range range = doc->textSelection();
         if ( !range.isValid() ) {
             range = KTextEditor::Range(doc->cursorPosition(), doc->cursorPosition());
@@ -114,6 +125,15 @@ void SnippetPlugin::insertSnippet(Snippet* snippet)
     }
 }
 
+void SnippetPlugin::insertSnippetFromActionData()
+{
+    KAction* action = dynamic_cast<KAction*>(sender());
+    Q_ASSERT(action);
+    Snippet* snippet = action->data().value<Snippet*>();
+    Q_ASSERT(snippet);
+    insertSnippet(snippet);
+}
+
 void SnippetPlugin::viewCreated( KTextEditor::Document*, KTextEditor::View* view )
 {
     KAction* selectionAction = view->actionCollection()->addAction("edit_selection_snippet", this, SLOT(createSnippetFromSelection()));
@@ -157,7 +177,7 @@ void SnippetPlugin::createSnippetFromSelection()
     Q_ASSERT(view);
 
     QString mode;
-    #ifdef HAVE_HIGHLIGHT_IFACE
+    #ifdef SNIPPETS_HAVE_HIGHLIGHTIFACE
         if ( KTextEditor::HighlightInterface* iface = qobject_cast<KTextEditor::HighlightInterface*>(view->document()) ) {
             mode = iface->highlightingModeAt(view->selectionRange().start());
         }
