@@ -27,10 +27,9 @@
 
 #include <KGlobalSettings>
 
-#include <kdeversion.h>
+#include "snippetfeatures.h"
 
-#if KDE_IS_VERSION( 4, 4, 0 )
-    #define SNIPPETS_HAVE_GHNS
+#ifdef SNIPPETS_HAVE_GHNS
     #include <KNS3/DownloadDialog>
     #include <knewstuff3/uploaddialog.h>
 #endif
@@ -70,10 +69,12 @@ SnippetView::SnippetView(SnippetPlugin* plugin, QWidget* parent)
     m_removeRepoAction = new KAction(KIcon("edit-delete"), i18n("Remove Repository"), this);
     connect(m_removeRepoAction, SIGNAL(triggered()), this, SLOT(slotRemoveRepo()));
     addAction(m_removeRepoAction);
-    ///TODO: reactivate once KNS3 is actually usable for uploading
-//     m_putNewStuffAction = new KAction(KIcon("get-hot-new-stuff"), i18n("Publish Repository"), this);
-//     connect(m_putNewStuffAction, SIGNAL(triggered()), this, SLOT(slotSnippetToGHNS()));
-//     addAction(m_putNewStuffAction);
+
+#ifdef SNIPPETS_ENABLE_GHNS_UPLOAD
+    m_putNewStuffAction = new KAction(KIcon("get-hot-new-stuff"), i18n("Publish Repository"), this);
+    connect(m_putNewStuffAction, SIGNAL(triggered()), this, SLOT(slotSnippetToGHNS()));
+    addAction(m_putNewStuffAction);
+#endif
 
     QAction* separator = new QAction(this);
     separator->setSeparator(true);
@@ -114,8 +115,9 @@ void SnippetView::validateActions()
     m_addRepoAction->setEnabled(true);
     m_editRepoAction->setEnabled(selectedRepo);
     m_removeRepoAction->setEnabled(selectedRepo);
-    ///TODO: reactivate once KNS3 is actually usable for uploading
-//     m_putNewStuffAction->setEnabled(selectedRepo);
+#ifdef SNIPPETS_ENABLE_GHNS_UPLOAD
+    m_putNewStuffAction->setEnabled(selectedRepo);
+#endif
 
     m_addSnippetAction->setEnabled(selectedRepo || selectedSnippet);
     m_editSnippetAction->setEnabled(selectedSnippet);
@@ -171,8 +173,9 @@ void SnippetView::contextMenu (const QPoint& pos)
 
         menu.addAction(m_editRepoAction);
         menu.addAction(m_removeRepoAction);
-        ///TODO: reactivate once KNS3 is actually usable for uploading
-//         menu.addAction(m_putNewStuffAction);
+#ifdef SNIPPETS_ENABLE_GHNS_UPLOAD
+        menu.addAction(m_putNewStuffAction);
+#endif
         menu.addSeparator();
 
         menu.addAction(m_addSnippetAction);
