@@ -479,6 +479,8 @@ void ProjectFolderItem::setUrl( const KUrl& url )
     KUrl copy(url);
     copy.adjustPath(KUrl::AddTrailingSlash);
     ProjectBaseItem::setUrl(copy);
+    
+    propagateRename(url);
 }
 
 ProjectFolderItem *ProjectFolderItem::folder() const
@@ -496,16 +498,18 @@ QString ProjectFolderItem::folderName() const
     return url().fileName();
 }
 
-void propagateRename( const KDevelop::ProjectFolderItem* item, const KUrl& newBase)
+void ProjectFolderItem::propagateRename(const KUrl& newBase) const
 {
     KUrl url = newBase;
     url.addPath("dummy");
-    foreach( KDevelop::ProjectBaseItem* child, item->children() )
+    foreach( KDevelop::ProjectBaseItem* child, children() )
     {
         url.setFileName( child->text() );
         child->setUrl( url );
-        if ( child->folder() ) {
-            propagateRename( child->folder(), url );
+        
+        const ProjectFolderItem* folder = child->folder();
+        if ( folder ) {
+            folder->propagateRename( url );
         }
     }
 }
@@ -523,10 +527,9 @@ ProjectBaseItem::RenameStatus ProjectFolderItem::rename(const QString& newname)
         {
             if( !project() || project()->projectFileManager()->renameFolder(this, dest) )
             {
-                setUrl( dest );
-                propagateRename(this, dest);
                 return ProjectBaseItem::RenameOk;
-            } else
+            }
+            else
             {
                 return ProjectBaseItem::ProjectManagerRenameFailed;
             }
@@ -611,9 +614,9 @@ ProjectBaseItem::RenameStatus ProjectFileItem::rename(const QString& newname)
         {
             if( !project() || project()->projectFileManager()->renameFile(this, dest) )
             {
-                setUrl( dest );
                 return ProjectBaseItem::RenameOk;
-            } else
+            }
+            else
             {
                 return ProjectBaseItem::ProjectManagerRenameFailed;
             }
