@@ -94,7 +94,6 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
     }
     tree->selectionModel()->select( QItemSelection( idx, idx ), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
     tree->selectionModel()->setCurrentIndex( idx, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
-    setInitialSize( QSize( 700, 500 ) );
     
     // Unfortunately tree->resizeColumnToContents() only looks at the top-level 
     // items, instead of all open ones. Hence we're calculating it ourselves like
@@ -118,11 +117,20 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
         level++;
         parentidx = parentidx.parent();
     }
-    int width = qMax( tree->columnWidth( 0 ), level*tree->indentation() + tree->indentation() + tree->sizeHintForIndex( widthidx ).width() );
+    // make sure the base column width is honored, e.g. when no launch configs exist
+    tree->resizeColumnToContents(0);
+    int width = tree->columnWidth( 0 );
+    while ( widthidx.isValid() )
+    {
+        width = qMax( width, level*tree->indentation() + tree->indentation() + tree->sizeHintForIndex( widthidx ).width() );
+        widthidx = widthidx.parent();
+    }
     tree->setColumnWidth( 0, width );
-    
+
     connect( this, SIGNAL(okClicked()), SLOT(saveConfig()) );
     connect( this, SIGNAL(applyClicked()), SLOT(saveConfig()) );
+
+    setInitialSize( QSize(qMax(700, sizeHint().width()), qMax(500, sizeHint().height())) );
 }
 
 void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemSelection deselected )
@@ -435,6 +443,15 @@ QVariant LaunchConfigurationsModel::data(const QModelIndex& index, int role) con
                 {
                     return lmi->mode->icon();
                 }
+                if ( index.column() == 0 && !index.parent().isValid() ) {
+                    if (index.row() == 0) {
+                        // global item
+                        return KIcon("folder");
+                    } else {
+                        // project item
+                        return KIcon("folder-development");
+                    }
+                }
             }
             case Qt::EditRole:
             {
