@@ -47,7 +47,7 @@ public:
     ~Container();
 
     /**Adds the widget for given @p view to the container.*/
-    void addWidget(View *view);
+    void addWidget(Sublime::View* view, int position = -1);
     /**Removes the widget from the container.*/
     void removeWidget(QWidget *w);
     /** @return true if widget is placed inside this container.*/
@@ -62,16 +62,17 @@ public:
     View *viewForWidget(QWidget *w) const;
 
     void setTabBarHidden(bool hide);
-    void setOpenAfterCurrent(bool after);
 
     /** Adds a corner widget to the left of this containers tab-bar. To remove it again, just delete it.
       * The ownership otherwise goes to the container. */
     void setLeftCornerWidget(QWidget* widget);
+    void showTooltipForTab(int tab);
 
 Q_SIGNALS:
     void activateView(Sublime::View* view);
     void closeRequest(QWidget *w);
     void tabContextMenuRequested(Sublime::View* view, KMenu* menu);
+    void tabToolTipRequested(Sublime::View* view, QPoint pos);
 
 private Q_SLOTS:
     void widgetActivated(int idx);
